PbxprojModifier class
Constructors
- PbxprojModifier(String projectRoot)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addFirebase(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDeploymentTarget(
) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited